% ultrasonic - analyse and plot data from ultrasonic reflection measurements
% Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
% License: MIT
% This program was written in the course of the lecture 'Anwendung ZfP- und Monitoringverfahren [206.554]'
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
% documentation files (the “Software”), to deal in the Software without restriction, including without 
% limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
% the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
% 
% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
help init;
disp(' ');
disp('Initialize program: ultrasonic');
disp('   setup additional program paths: tools');
addpath('tools');
disp(' ');
disp('Using MatLab graphics toolkit');
disp(' ');
disp('Ultrasonic measurement device: ACS Monolith-3D A1220');
disp('   Sample rate: r = 25000000 [Hz] (25 MHz)');
disp('   Max samples: n = 40000 [samples] (40 kS)');
disp('');
disp('Material properties: Concrete');
disp('   Speed of sound: vs ~ 3100 [m/s]');
fprintf('   d = 100mm: %d [samples]\n', fix(0.1/3100*25e6));
fprintf('   d = 200mm: %d [samples]\n', fix(0.2/3100*25e6));
fprintf('   d = 300mm: %d [samples]\n', fix(0.3/3100*25e6));
fprintf('   d = 400mm: %d [samples]\n', fix(0.4/3100*25e6));
fprintf('   d = 500mm: %d [samples]\n', fix(0.5/3100*25e6));
fprintf('   d = 600mm: %d [samples]\n', fix(0.6/3100*25e6));
disp(' ');
disp('Tasks to be performed:');
disp('   Step 0: copy your measurement data folder into program folder [projects], initialize program and load data');
disp('           >> init');
disp('           >> ds = us_read_project(your_measurement_data_folder);');
disp('           note: embrace the folder name with single or double quotes');
disp('   Step 1: calibrate speed of sound to known measurement distance');
disp('           >> vs = us_calibrate(ds, 2, 2)');
disp('           note: start with the center grid point, row = 2, column = 2');
disp('   Step 2: analyse all grid point signals with calibrated speed of sound');
disp('           >> vs = us_analyse(ds, ...)');
disp('           note: after step 1 help on function parameters for the analysis is given');
disp(' ');
disp('Help is available for all function files:');
disp('   >> help us_init');
disp('   >> help us_read_project');
disp('   >> help us_calibrate');
disp('   >> help us_analyse');
