% ultrasonic - analyse and plot data from ultrasonic reflection measurements
% Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
% License: MIT
% This program was written in the course of the lecture 'Anwendung ZfP- und Monitoringverfahren [206.554]'
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
% documentation files (the “Software”), to deal in the Software without restriction, including without 
% limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
% the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
% 
% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Compute speed of sound of medium from known measurement distance
%
% Usage: [r_ss] = us_calc_speed(p_ds, p_di, p_ns)
%
% p_ds ... grid point data, structure
% p_di ... known distance (unit: m), double
% p_ns ... start index of the detected reflection (number of samples), integer
% r_ss ... return: speed of sound (unit: m/s), double
%
% Note: for details on grid data structure see function file us_createstruct.m
%
function [r_ss] = us_calc_speed(p_ds, p_di, p_ns)
  
  % check arguments
  if (nargin < 3)
    help us_calc_speed;
    error('Missing function arguments!');
  end
  if (not(us_checkstruct(p_ds, 1)))
    help us_calc_speed;
    error('Wrong argument type (grid point data structure)!');
  end
  
  % init return value
  r_ss = 0.0;
  
  % compute speed of sound
  r_ss = p_di * p_ds.sr / p_ns;
  
end
