% ultrasonic - analyse and plot data from ultrasonic reflection measurements
% Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
% License: MIT
% This program was written in the course of the lecture 'Anwendung ZfP- und Monitoringverfahren [206.554]'
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
% documentation files (the “Software”), to deal in the Software without restriction, including without 
% limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
% the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
% 
% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Check data structure
%
% Usage: [r_stat] = us_checkstruct(p_tp, p_ds)
%
% p_ds ... data structure, structure
% p_tp ... data structure type, integer, default = 0
%            0: structure of any type
%            1: grid point measurement data structure
%            2: project measurement data structure
% r_stat ... return: state indicating whether data structure is of requested type or not
%
function [r_stat] = us_checkstruct(p_ds, p_tp)
  
  % check arguments
  if (nargin < 2)
    p_tp = 0;
  end
  if (nargin < 1)
    help us_checkstruct;
    error('Missing function arguments!');
  end
  
  % check if is of type structure
  if (not(isstruct(p_ds)))
    help us_checkstruct;
    error('Given data structure is not of type structure!');
  end
  
  % check whether structure contains the object descriptor field
  if (not(isfield(p_ds, 'obj_type')))
    help us_checkstruct;
    error('Given data structure type has wrong format!\n  missing field: obj_type');
  end
  
  % check object type
  r_stat = false;
  switch (p_tp)
    case 0 % any type
      r_stat = true;
    case 1 % grid point measurement data
      if (strcmp(p_ds.obj_type, 'obj_gridpoint'))
        r_stat = true;
      end
    case 2 % grid measurement data
      if (strcmp(p_ds.obj_type, 'obj_grid'))
        r_stat = true;
      end
    case 3 % grid point wavelet analysis data
      if (strcmp(p_ds.obj_type, 'obj_wavelet_gridpoint'))
        r_stat = true;
      end
    case 4 % grid wavelet analysis data
      if (strcmp(p_ds.obj_type, 'obj_wavelet_grid'))
        r_stat = true;
      end
    otherwise
      warning('Unknown data structure type!\n  type: %d', p_tp);
  end
  
end
