% ultrasonic - analyse and plot data from ultrasonic reflection measurements
% Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
% License: MIT
% This program was written in the course of the lecture 'Anwendung ZfP- und Monitoringverfahren [206.554]'
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
% documentation files (the “Software”), to deal in the Software without restriction, including without 
% limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
% the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
% 
% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Read all measurement data files of one project (complete measurement grid)
%
% Usage: [r_ds] = us_dread(p_pp)
%
% p_pn ... project directory name, string
% r_ds ... grid data, structure
%
% Note: see us_createstruct for details on structure fields
%
function [r_ds] = us_dread(p_pn)
  
  % check arguments
  if (nargin < 1)
    help us_dread;
    error('Missing function arguments!');
  end
  
  % create project directory path
  pp = sprintf('%s%s%s%s%s', '.', filesep(), 'projects', filesep(), p_pn);
  
  % check whether project directory exists
  if (exist(pp, 'dir') ~= 7)
    help us_dread;
    error('Project data directory does not exist!\n  path = %s', pp);
  end
  
  % create empty data structure
  r_ds = us_createstruct(2);
  
  % get list of measurement data files (*.raw)
  flst = dir(sprintf('%s%s%s', pp, filesep(), '*.raw'));
  
  % update protocol
  %r_ds = us_update_protocol(r_ds, sprintf('us_dread(\'%s\')', pp), 'Read data from project directory');
  
  % read measurement data files and create data structure
  r_ds.dp = pp;
  for i = 1 : max(size(flst))
    fp = sprintf('%s%s%s', flst(i).folder, filesep(), flst(i).name);
    ds = us_fread(fp);
    if (ds.nn > 0)
      r_ds.nn = r_ds.nn + 1;
      r_ds.nx = max([r_ds.nx, ds.ix]);
      r_ds.ny = max([r_ds.ny, ds.iy]);
      r_ds.arr_ds(ds.iy, ds.ix) = ds;
      % update protocol
      %r_ds = us_update_protocol(r_ds, sprintf('us_fread(\'%s\')', fp), 'Read data from project file');
    end
  end
  
end
