% ultrasonic - analyse and plot data from ultrasonic reflection measurements
% Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
% License: MIT
% This program was written in the course of the lecture 'Anwendung ZfP- und Monitoringverfahren [206.554]'
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
% documentation files (the “Software”), to deal in the Software without restriction, including without 
% limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
% the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
% 
% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Update sample rate and speed of sound of a project
%
% Usage: [r_ds] = us_update_protocol(p_ds, p_fn, p_cm) ... add comment line to protocol   
%
% p_ds ... project measurement data structure or grid point measurement data structure, structure
% p_fn ... function name, string
% p_cm ... comment, string
% r_ds ... return: data structure, structure
%
% Note: see us_createstruct for details on structure fields
%
function [r_ds] = us_update_protocol(p_ds, p_fn, p_cm)
  
  % check arguments
  if (nargin < 3)
    help us_update_protocol;
    error('Missing function arguments!');
  end
  if (not(us_checkstruct(p_ds, 0)))
    help us_update_protocol;
    error('Wrong argument type (data structure)!');
  end
  if (isempty(p_fn))
    help us_update_protocol;
    error('Calling function name is empty!');
  end
  if (isempty(p_cm))
    help us_update_protocol;
    error('Comment line is empty!');
  end
  
  % copy structure
  r_ds = p_ds;
  
  % get username
  un = getenv('USERNAME');
  
  % get time
  tm = ctime(time());
  
  % update structure
  if (strcmp(p_ds.obj_type, 'obj_gridpoint')) % grid point
    r_ds.proto = [r_ds.proto; un, tm, p_fn, p_cm];
  elseif (strcmp(p_ds.obj_type, 'obj_grid')) % grid
    r_ds.proto = [r_ds.proto; un, tm, p_fn, p_cm];
%    for i = 1 : p_ds.nx
%      for j = 1 : p_ds.ny
%        r_ds.arr_ds(i, j).proto = [r_ds.arr_ds(i, j).proto; un, tm, p_fn, p_cm];
%      end
%    end
  end
  
end
