% ultrasonic - analyse and plot data from ultrasonic reflection measurements
% Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
% License: MIT
% This program was written in the course of the lecture 'Anwendung ZfP- und Monitoringverfahren [206.554]'
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
% documentation files (the “Software”), to deal in the Software without restriction, including without 
% limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
% the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
% 
% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Update speed of sound and sample distance of a grid point data structure
%
% Usage: [r_ds] = us_update_smpdist(p_ds, p_ss)
%
% p_ds ... grid point data, structure
% p_ss ... speed of sound (unit: m/sec), default = 1500, double, p_ss >= 1.0
% r_ds ... return: updated grid point data, structure
%
% Note: see us_createstruct for details on structure fields
%
function [r_ds] = us_update_smpdist(p_ds, p_ss)
  
  % check arguments
  if (nargin < 1)
    help us_update_smpdist;
    error('Missing function arguments!');
  end
  if (nargin < 2)
    p_ss = 3000;
  end
  if (isempty(p_ss))
    p_ss = 3000;
  end
  if (p_ss < 1.0)
    help us_update_smpdist;
    error('Given speed of sound < 1.0!\n  speed of sound = %.1f', p_ss);
  end
  if (not(us_checkstruct(p_ds, 1)))
    help us_update_smpdist;
    return;
  end
  
  % copy structure
  r_ds = p_ds;
  
  % update speed of sound
  r_ds.ss = p_ss;
  
  % update structure
  r_ds.xx_d = 0.5 * r_ds.xx_t * r_ds.ss;
  
  % update protocol
  %r_ds = us_update_protocol(r_ds, sprintf('us_update_smpdist(\'%s\', %.1f)', p_ds.obj_type, p_ss), sprintf('Updated speed of sound and sample distance'));
  
end
