% ultrasonic - analyse and plot data from ultrasonic reflection measurements
% Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
% License: MIT
% This program was written in the course of the lecture 'Anwendung ZfP- und Monitoringverfahren [206.554]'
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
% documentation files (the “Software”), to deal in the Software without restriction, including without 
% limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
% the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
% 
% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Update sample rate and sample time of grid point data structure
%
% Usage: [r_ds] = us_update_smptime(p_ds, p_sr)
%
% p_ds ... grid point measurement data structure, structure
% p_sr ... sample rate (unit: Hz), default = 5500000, integer, p_sr >= 1
% r_ds ... return: updated grid point data, structure
%
% Note: see us_createstruct for details on structure fields
%
function [r_ds] = us_update_smptime(p_ds, p_sr)
  
  % check arguments
  if (nargin < 1)
    help us_update_smptime;
    error('Missing function arguments!');
  end
  if (nargin < 2)
    p_sr = 25000000;
  end
  if (isempty(p_sr))
    p_sr = 25000000;
  end
  if (p_sr < 1)
    help us_update_smptime;
    error('Given sample rate < 1!\n  sample rate = %d', p_sr);
  end
  if (not(us_checkstruct(p_ds, 1)))
    help us_update_smptime;
    return;
  end
  
  % copy structure
  r_ds = p_ds;
  
  % update sample rate
  r_ds.sr = p_sr;
  
  % delta t for sample times
  dts = 1.0 / p_sr;
  
  % update structure
  r_ds.xx_t = r_ds.xx_n .* dts;
  
  % update protocol
  %r_ds = us_update_protocol(r_ds, sprintf('us_update_smptime(\'%s\', %d)', p_ds.obj_type, p_sr), sprintf('Updated sample rate and sample time'));
  
end
